from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_audio import RootTypeForXMLStreamingChannelAudio
    from ..models.root_type_for_xml_streaming_channel_transport import RootTypeForXMLStreamingChannelTransport
    from ..models.root_type_for_xml_streaming_channel_video import RootTypeForXMLStreamingChannelVideo


T = TypeVar("T", bound="RootTypeForXMLStreamingChannel")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannel:
    """StreamingChannel message in XML format

    Example:
        {'id': '101', 'channelName': 'Camera 01', 'enabled': 'true', 'Transport': {'ControlProtocolList':
            {'ControlProtocol': [{'streamingTransport': 'RTSP'}, {'streamingTransport': 'HTTP'}]}, 'Security': {'enabled':
            'true'}}, 'Video': {'enabled': 'true', 'videoInputChannelID': '1', 'videoCodecType': 'H.264', 'videoScanType':
            'progressive', 'videoResolutionWidth': '1280', 'videoResolutionHeight': '720', 'videoQualityControlType': 'VBR',
            'constantBitRate': '2048', 'fixedQuality': '60', 'vbrUpperCap': '2048', 'vbrLowerCap': '32', 'maxFrameRate':
            '2500', 'keyFrameInterval': '2000', 'snapShotImageType': 'JPEG', 'GovLength': '50'}, 'Audio': {'enabled':
            'true', 'audioInputChannelID': '1', 'audioCompressionType': 'G.711ulaw'}}

    Attributes:
        id (Union[Unset, str]):
        channel_name (Union[Unset, str]):
        enabled (Union[Unset, str]):
        transport (Union[Unset, RootTypeForXMLStreamingChannelTransport]):
        video (Union[Unset, RootTypeForXMLStreamingChannelVideo]):
        audio (Union[Unset, RootTypeForXMLStreamingChannelAudio]):
    """

    id: Union[Unset, str] = UNSET
    channel_name: Union[Unset, str] = UNSET
    enabled: Union[Unset, str] = UNSET
    transport: Union[Unset, "RootTypeForXMLStreamingChannelTransport"] = UNSET
    video: Union[Unset, "RootTypeForXMLStreamingChannelVideo"] = UNSET
    audio: Union[Unset, "RootTypeForXMLStreamingChannelAudio"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        channel_name = self.channel_name
        enabled = self.enabled
        transport: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.transport, Unset):
            transport = self.transport.to_dict()

        video: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video, Unset):
            video = self.video.to_dict()

        audio: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio, Unset):
            audio = self.audio.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if channel_name is not UNSET:
            field_dict["channelName"] = channel_name
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if transport is not UNSET:
            field_dict["Transport"] = transport
        if video is not UNSET:
            field_dict["Video"] = video
        if audio is not UNSET:
            field_dict["Audio"] = audio

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_audio import RootTypeForXMLStreamingChannelAudio
        from ..models.root_type_for_xml_streaming_channel_transport import RootTypeForXMLStreamingChannelTransport
        from ..models.root_type_for_xml_streaming_channel_video import RootTypeForXMLStreamingChannelVideo

        d = src_dict.copy()
        id = d.pop("id", UNSET)

        channel_name = d.pop("channelName", UNSET)

        enabled = d.pop("enabled", UNSET)

        _transport = d.pop("Transport", UNSET)
        transport: Union[Unset, RootTypeForXMLStreamingChannelTransport]
        if isinstance(_transport, Unset):
            transport = UNSET
        else:
            transport = RootTypeForXMLStreamingChannelTransport.from_dict(_transport)

        _video = d.pop("Video", UNSET)
        video: Union[Unset, RootTypeForXMLStreamingChannelVideo]
        if isinstance(_video, Unset):
            video = UNSET
        else:
            video = RootTypeForXMLStreamingChannelVideo.from_dict(_video)

        _audio = d.pop("Audio", UNSET)
        audio: Union[Unset, RootTypeForXMLStreamingChannelAudio]
        if isinstance(_audio, Unset):
            audio = UNSET
        else:
            audio = RootTypeForXMLStreamingChannelAudio.from_dict(_audio)

        root_type_for_xml_streaming_channel = cls(
            id=id,
            channel_name=channel_name,
            enabled=enabled,
            transport=transport,
            video=video,
            audio=audio,
        )

        root_type_for_xml_streaming_channel.additional_properties = d
        return root_type_for_xml_streaming_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import hashlib
import logging
import random
import time
from http import HTTPStatus
from typing import Dict

from hikvision_isapi_cli import Client
from hikvision_isapi_cli.api.default import session_heartbeat, session_login, session_login_capabilities
from hikvision_isapi_cli.models.root_type_for_xml_session_login import RootTypeForXMLSessionLogin
from hikvision_isapi_cli.models.root_type_for_xml_session_login_cap import RootTypeForXMLSessionLoginCap
from hikvision_isapi_cli.models.root_type_for_xml_session_login_session_login import (
    RootTypeForXMLSessionLoginSessionLogin,
)
from hikvision_isapi_cli.types import Response

_LOGGER = logging.getLogger(__name__)


class Session(object):

    __length = 8

    def __init__(self, client: Client) -> None:
        self.client = client

    def __sha256(self, msg: str) -> str:
        return hashlib.sha256(msg.encode("utf-8")).hexdigest()

    def __encodePwd(self, model: Dict[str, str], is_irreversible: bool) -> str:
        if is_irreversible:
            encode = self.__sha256(model["username"] + model["salt"] + self.client.password)
            encode = self.__sha256(encode + model["challenge"])
            for i in range(2, int(model["iterations"])):
                encode = self.__sha256(encode)
        else:
            encode = self.__sha256(self.client.password) + model["challenge"]
            for a in range(1, int(model["iterations"])):
                encode = self.__sha256(encode)
        return encode

    def start(self) -> None:

        random_number = random.randint(10 ** (self.__length - 1), 10**self.__length - 1)
        session_cap: RootTypeForXMLSessionLoginCap = session_login_capabilities.sync(
            client=self.client, username=self.client.username, random=random_number
        )
        session_login_cap = session_cap.session_login_cap

        encoded = self.__encodePwd(
            model={
                "challenge": session_login_cap.challenge,
                "username": self.client.username,
                "salt": session_login_cap.salt,
                "iterations": session_login_cap.iterations,
            },
            is_irreversible=session_login_cap.is_irreversible,
        )

        millis = int(round(time.time() * 1000))
        login = RootTypeForXMLSessionLogin()
        login.session_login = RootTypeForXMLSessionLoginSessionLogin()
        login.session_login.user_name = self.client.username
        login.session_login.password = encoded
        login.session_login.session_id = session_login_cap.session_id
        login.session_login.is_support_session_tag = False
        login.session_login.is_session_id_valid_long_term = True
        login.session_login.session_id_version = 2

        response: Response = session_login.sync_detailed(client=self.client, time_stamp=millis, json_body=login)
        cookies = response.headers["set-cookie"]
        web_session = cookies.split(";")[0].split("=")

        self.client.cookies = {web_session[0]: web_session[1], "Connection": "Keep-Alive"}
        self.client._api.cookies = self.client.cookies
        self.client._asyncio_api.cookies = self.client.cookies

        response: Response = session_heartbeat.sync_detailed(client=self.client)
        if response.status_code == HTTPStatus.OK:
            return True

        _LOGGER.error(response)
        return False

    def stop(self) -> None:
        _LOGGER.info("Stop Web Session: " + str(self.client._api.cookies))
        self.client.cookies = {}
        self.client._api.cookies = {}
        self.client._asyncio_api.cookies = {}

    async def heartbeat(self) -> bool:
        response: Response = await session_heartbeat.asyncio_detailed(client=self.client)
        if response.status_code == HTTPStatus.OK:
            return True
        return False



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_network_interface_list_network_interface_list import (
        RootTypeForXMLNetworkInterfaceListNetworkInterfaceList,
    )


T = TypeVar("T", bound="RootTypeForXMLNetworkInterfaceList")


@attr.s(auto_attribs=True)
class RootTypeForXMLNetworkInterfaceList:
    """NetworkInterfaceList message in XML format

    Example:
        {'NetworkInterfaceList': {'NetworkInterface': [], '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        network_interface_list (Union[Unset, RootTypeForXMLNetworkInterfaceListNetworkInterfaceList]):
    """

    network_interface_list: Union[Unset, "RootTypeForXMLNetworkInterfaceListNetworkInterfaceList"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        network_interface_list: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.network_interface_list, Unset):
            network_interface_list = self.network_interface_list.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if network_interface_list is not UNSET:
            field_dict["NetworkInterfaceList"] = network_interface_list

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_network_interface_list_network_interface_list import (
            RootTypeForXMLNetworkInterfaceListNetworkInterfaceList,
        )

        d = src_dict.copy()
        _network_interface_list = d.pop("NetworkInterfaceList", UNSET)
        network_interface_list: Union[Unset, RootTypeForXMLNetworkInterfaceListNetworkInterfaceList]
        if isinstance(_network_interface_list, Unset):
            network_interface_list = UNSET
        else:
            network_interface_list = RootTypeForXMLNetworkInterfaceListNetworkInterfaceList.from_dict(
                _network_interface_list
            )

        root_type_for_xml_network_interface_list = cls(
            network_interface_list=network_interface_list,
        )

        root_type_for_xml_network_interface_list.additional_properties = d
        return root_type_for_xml_network_interface_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list_video_input_channel_id import (
        RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID,
    )


T = TypeVar("T", bound="RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList")


@attr.s(auto_attribs=True)
class RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList:
    """
    Attributes:
        video_input_channel_id (Union[Unset, RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideo
            InputChannelListVideoInputChannelID]):
    """

    video_input_channel_id: Union[
        Unset,
        "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID",
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        video_input_channel_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_input_channel_id, Unset):
            video_input_channel_id = self.video_input_channel_id.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if video_input_channel_id is not UNSET:
            field_dict["videoInputChannelID"] = video_input_channel_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list_video_input_channel_id import (
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID,
        )

        d = src_dict.copy()
        _video_input_channel_id = d.pop("videoInputChannelID", UNSET)
        video_input_channel_id: Union[
            Unset,
            RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID,
        ]
        if isinstance(_video_input_channel_id, Unset):
            video_input_channel_id = UNSET
        else:
            video_input_channel_id = RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID.from_dict(
                _video_input_channel_id
            )

        root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list = cls(
            video_input_channel_id=video_input_channel_id,
        )

        root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list.additional_properties = (
            d
        )
        return root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_network_interface_network_interface import (
        RootTypeForXMLNetworkInterfaceNetworkInterface,
    )


T = TypeVar("T", bound="RootTypeForXMLNetworkInterface")


@attr.s(auto_attribs=True)
class RootTypeForXMLNetworkInterface:
    """NetworkInterface message in XML format

    Example:
        {'NetworkInterface': {'id': '', 'IPAddress': '', 'Wireless': '', 'Discovery': '', 'Link': '',
            'defaultConnection': '', 'ActiveMulticast': {'enabled': '', 'streamID': {'@opt': 'main'}, 'ipV4Address': '',
            'ipV6Address': '', 'port': {'@min': '', '@max': ''}}, 'macAddress': {'@min': '', '@max': ''},
            'EthernetPortList': {'EthernetPort': {'id': '', 'MACAddress': '', 'status': '', 'speed': ''}, '@size': '4'},
            '@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        network_interface (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterface]):
    """

    network_interface: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterface"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        network_interface: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.network_interface, Unset):
            network_interface = self.network_interface.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if network_interface is not UNSET:
            field_dict["NetworkInterface"] = network_interface

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_network_interface_network_interface import (
            RootTypeForXMLNetworkInterfaceNetworkInterface,
        )

        d = src_dict.copy()
        _network_interface = d.pop("NetworkInterface", UNSET)
        network_interface: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterface]
        if isinstance(_network_interface, Unset):
            network_interface = UNSET
        else:
            network_interface = RootTypeForXMLNetworkInterfaceNetworkInterface.from_dict(_network_interface)

        root_type_for_xml_network_interface = cls(
            network_interface=network_interface,
        )

        root_type_for_xml_network_interface.additional_properties = d
        return root_type_for_xml_network_interface

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLResponseStatusResponseStatus")


@attr.s(auto_attribs=True)
class RootTypeForXMLResponseStatusResponseStatus:
    """
    Attributes:
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
        request_url (Union[Unset, str]):
        status_code (Union[Unset, str]):
        status_string (Union[Unset, str]):
        sub_status_code (Union[Unset, str]):
    """

    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    request_url: Union[Unset, str] = UNSET
    status_code: Union[Unset, str] = UNSET
    status_string: Union[Unset, str] = UNSET
    sub_status_code: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        version = self.version
        xmlns = self.xmlns
        request_url = self.request_url
        status_code = self.status_code
        status_string = self.status_string
        sub_status_code = self.sub_status_code

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns
        if request_url is not UNSET:
            field_dict["requestURL"] = request_url
        if status_code is not UNSET:
            field_dict["statusCode"] = status_code
        if status_string is not UNSET:
            field_dict["statusString"] = status_string
        if sub_status_code is not UNSET:
            field_dict["subStatusCode"] = sub_status_code

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        request_url = d.pop("requestURL", UNSET)

        status_code = d.pop("statusCode", UNSET)

        status_string = d.pop("statusString", UNSET)

        sub_status_code = d.pop("subStatusCode", UNSET)

        root_type_for_xml_response_status_response_status = cls(
            version=version,
            xmlns=xmlns,
            request_url=request_url,
            status_code=status_code,
            status_string=status_string,
            sub_status_code=sub_status_code,
        )

        root_type_for_xml_response_status_response_status.additional_properties = d
        return root_type_for_xml_response_status_response_status

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.root_type_for_json_cap_call_status import RootTypeForJSONCapCallStatus
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    format_: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/ISAPI/VideoIntercom/callStatus/capabilities".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["format"] = format_

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[RootTypeForJSONCapCallStatus]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RootTypeForJSONCapCallStatus.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[RootTypeForJSONCapCallStatus]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    format_: Union[Unset, None, str] = UNSET,
) -> Response[RootTypeForJSONCapCallStatus]:
    """callStatus/capabilities?format=json

     callStatus/capabilities?format=json

    Args:
        format_ (Union[Unset, None, str]):  Example: json.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForJSONCapCallStatus]
    """

    kwargs = _get_kwargs(
        client=client,
        format_=format_,
    )

    response = client._api.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    format_: Union[Unset, None, str] = UNSET,
) -> Optional[RootTypeForJSONCapCallStatus]:
    """callStatus/capabilities?format=json

     callStatus/capabilities?format=json

    Args:
        format_ (Union[Unset, None, str]):  Example: json.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForJSONCapCallStatus]
    """

    return sync_detailed(
        client=client,
        format_=format_,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    format_: Union[Unset, None, str] = UNSET,
) -> Response[RootTypeForJSONCapCallStatus]:
    """callStatus/capabilities?format=json

     callStatus/capabilities?format=json

    Args:
        format_ (Union[Unset, None, str]):  Example: json.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForJSONCapCallStatus]
    """

    kwargs = _get_kwargs(
        client=client,
        format_=format_,
    )

    response = await client._asyncio_api.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    format_: Union[Unset, None, str] = UNSET,
) -> Optional[RootTypeForJSONCapCallStatus]:
    """callStatus/capabilities?format=json

     callStatus/capabilities?format=json

    Args:
        format_ (Union[Unset, None, str]):  Example: json.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForJSONCapCallStatus]
    """

    return (
        await asyncio_detailed(
            client=client,
            format_=format_,
        )
    ).parsed
